"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MonitorServer = void 0;
const socket_io_1 = require("socket.io");
const http_1 = __importDefault(require("http"));
const serve_static_1 = __importDefault(require("serve-static"));
const fs_1 = require("fs");
const redis_client_1 = require("./redis-client");
const assetsDir = `${__dirname}/../../assets`;
function MonitorServer(config) {
    if (!config) {
        throw new Error('Configuration object is required.');
    }
    if (typeof config !== 'object') {
        throw new Error('Invalid argument type');
    }
    if (!config.monitor || !config.monitor.enabled) {
        throw new Error('RedisSMQ monitor is not enabled. Exiting...');
    }
    const { host = '0.0.0.0', port = 7210, socketOpts = {} } = config.monitor;
    return {
        listen(cb) {
            const fallback = (req, res) => {
                return () => {
                    fs_1.readFile(`${assetsDir}/index.html`, (err, content) => {
                        res.writeHead(200, { 'Content-Type': 'text/html' });
                        res.end(content);
                    });
                };
            };
            const serve = serve_static_1.default(assetsDir, {
                index: 'index.html',
                dotfiles: 'deny'
            });
            const server = http_1.default.createServer((req, res) => {
                serve(req, res, fallback(req, res));
            });
            const io = new socket_io_1.Server(server, Object.assign(Object.assign({}, socketOpts), { cors: {
                    origin: '*'
                } }));
            console.log('Connecting to Redis server...');
            redis_client_1.RedisClient(config, (err, client) => {
                if (err) {
                    console.log('An error occurred while trying to connect to Redis server.');
                    throw err;
                }
                console.log('Successfully connected to Redis server.');
                client.subscribe('stats');
                client.on('message', (channel, message) => {
                    const json = JSON.parse(message);
                    io.emit('stats', json);
                });
                server.listen(port, host, () => {
                    console.log(`Listening for HTTP connections on ${host}:${port}...`);
                    cb && cb();
                });
            });
        }
    };
}
exports.MonitorServer = MonitorServer;
//# sourceMappingURL=index.js.map